@@ -32,6 +32,11 @@
 #ifndef VIPS_FOREIGN_H
 #define VIPS_FOREIGN_H
 
+#include <glib.h>
+#include <glib-object.h>
+#include <vips/object.h>
+#include <vips/operation.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /*__cplusplus*/
@@ -79,11 +84,13 @@ typedef struct _VipsForeignClass {
 
 /* Don't put spaces around void here, it breaks gtk-doc.
  */
+VIPS_API
 GType vips_foreign_get_type(void);
 
 /* Map over and find formats. This uses type introspection to loop over
  * subclasses of VipsForeign.
  */
+VIPS_API
 void *vips_foreign_map( const char *base, 
 	VipsSListMap2Fn fn, void *a, void *b );
 
@@ -258,19 +265,28 @@ typedef struct _VipsForeignLoadClass {
 
 /* Don't put spaces around void here, it breaks gtk-doc.
  */
+VIPS_API
 GType vips_foreign_load_get_type(void);
 
+VIPS_API
 const char *vips_foreign_find_load( const char *filename );
+VIPS_API
 const char *vips_foreign_find_load_buffer( const void *data, size_t size );
+VIPS_API
 const char *vips_foreign_find_load_source( VipsSource *source );
 
+VIPS_API
 VipsForeignFlags vips_foreign_flags( const char *loader, const char *filename );
+VIPS_API
 gboolean vips_foreign_is_a( const char *loader, const char *filename );
+VIPS_API
 gboolean vips_foreign_is_a_buffer( const char *loader, 
 	const void *data, size_t size );
+VIPS_API
 gboolean vips_foreign_is_a_source( const char *loader, 
 	VipsSource *source );
 
+VIPS_API
 void vips_foreign_load_invalidate( VipsImage *image );
 
 #define VIPS_TYPE_FOREIGN_SAVE (vips_foreign_save_get_type())
@@ -371,24 +387,35 @@ typedef struct _VipsForeignSaveClass {
 
 /* Don't put spaces around void here, it breaks gtk-doc.
  */
+VIPS_API
 GType vips_foreign_save_get_type(void);
 
+VIPS_API
 const char *vips_foreign_find_save( const char *filename );
+VIPS_API
 gchar **vips_foreign_get_suffixes( void );
+VIPS_API
 const char *vips_foreign_find_save_buffer( const char *suffix );
+VIPS_API
 const char *vips_foreign_find_save_target( const char *suffix );
 
+VIPS_API
 int vips_vipsload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_vipsload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_vipssave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_vipssave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_openslideload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_openslideload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
 
@@ -424,19 +451,26 @@ typedef enum {
 	VIPS_FOREIGN_JPEG_SUBSAMPLE_LAST
 } VipsForeignJpegSubsample;
 
+VIPS_API
 int vips_jpegload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jpegload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jpegload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_jpegsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jpegsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jpegsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jpegsave_mime( VipsImage *in, ... )
 	__attribute__((sentinel));
 
@@ -461,19 +495,26 @@ typedef enum {
 	VIPS_FOREIGN_WEBP_PRESET_LAST
 } VipsForeignWebpPreset;
 
+VIPS_API
 int vips_webpload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_webpload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_webpload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_webpsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_webpsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_webpsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_webpsave_mime( VipsImage *in, ... )
 	__attribute__((sentinel));
 
@@ -541,62 +582,90 @@ typedef enum {
 	VIPS_FOREIGN_TIFF_RESUNIT_LAST
 } VipsForeignTiffResunit;
 
+VIPS_API
 int vips_tiffload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_tiffload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_tiffload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_tiffsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_tiffsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
+int vips_tiffsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
+VIPS_API
 int vips_openexrload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_fitsload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_fitssave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_analyzeload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_rawload( const char *filename, VipsImage **out, 
 	int width, int height, int bands, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_rawsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_rawsave_fd( VipsImage *in, int fd, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_csvload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_csvload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_csvsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_csvsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_matrixload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_matrixload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_matrixsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_matrixsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_matrixprint( VipsImage *in, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_magickload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_magickload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_magicksave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_magicksave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
 
@@ -621,16 +690,22 @@ typedef enum /*< flags >*/ {
 	VIPS_FOREIGN_PNG_FILTER_ALL = 0xF8
 } VipsForeignPngFilter;
 
+VIPS_API
 int vips_pngload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pngload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pngload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pngsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pngsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pngsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
 
@@ -659,104 +734,149 @@ typedef enum {
 	VIPS_FOREIGN_PPM_FORMAT_LAST
 } VipsForeignPpmFormat;
 
+VIPS_API
 int vips_ppmload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_ppmload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_ppmsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_ppmsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_matload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_radload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_radload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_radload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_radsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_radsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_radsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_pdfload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pdfload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_pdfload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_svgload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_svgload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_svgload_string( const char *str, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_svgload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_gifload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_gifload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_gifload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_gifsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_gifsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_gifsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_heifload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_heifload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_heifload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_heifsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_heifsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_heifsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_niftiload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_niftiload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_niftisave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_jp2kload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jp2kload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jp2kload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jp2ksave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jp2ksave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jp2ksave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
+VIPS_API
 int vips_jxlload_source( VipsSource *source, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jxlload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jxlload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jxlsave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jxlsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
 	__attribute__((sentinel));
+VIPS_API
 int vips_jxlsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
 
@@ -809,8 +929,15 @@ typedef enum {
 	VIPS_FOREIGN_DZ_CONTAINER_LAST
 } VipsForeignDzContainer;
 
+VIPS_API
 int vips_dzsave( VipsImage *in, const char *name, ... )
 	__attribute__((sentinel));
+VIPS_API
+int vips_dzsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
+	__attribute__((sentinel));
+VIPS_API
+int vips_dzsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
 /**
  * VipsForeignHeifCompression:
